==> qt-creator-2.4.0-src.tar.gz: qt-creator-2.4.0-src/src/plugins/cpaster/pasteselectdialog.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/

#ifndef PASTESELECTDIALOG_H
#define PASTESELECTDIALOG_H

#include "ui_pasteselect.h"

#include <QtCore/QList>

QT_FORWARD_DECLARE_CLASS(QPushButton)

namespace CodePaster {
class Protocol;

class PasteSelectDialog : public QDialog
{
    Q_OBJECT
public:
    explicit PasteSelectDialog(const QList<Protocol*> &protocols,
                               QWidget *parent = 0);
    ~PasteSelectDialog();

    QString pasteId() const;

    QString protocol() const;
    void setProtocol(const QString &);

    int protocolIndex() const;

signals:

private slots:
    void protocolChanged(int);
    void list();
    void listDone(const QString &name, const QStringList &items);

private:
    const QList<Protocol*> m_protocols;

    Ui_PasteSelectDialog m_ui;
    QPushButton *m_refreshButton;
};

} // namespace CodePaster

#endif // PASTESELECTDIALOG_H

==> qt-creator-2.5.2-src.tar.gz: qt-creator-2.5.2-src/src/plugins/cpaster/pasteselectdialog.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/

#ifndef PASTESELECTDIALOG_H
#define PASTESELECTDIALOG_H

#include "ui_pasteselect.h"

#include <QList>

QT_FORWARD_DECLARE_CLASS(QPushButton)

namespace CodePaster {
class Protocol;

class PasteSelectDialog : public QDialog
{
    Q_OBJECT
public:
    explicit PasteSelectDialog(const QList<Protocol*> &protocols,
                               QWidget *parent = 0);
    ~PasteSelectDialog();

    QString pasteId() const;

    QString protocol() const;
    void setProtocol(const QString &);

    int protocolIndex() const;

signals:

private slots:
    void protocolChanged(int);
    void list();
    void listDone(const QString &name, const QStringList &items);

private:
    const QList<Protocol*> m_protocols;

    Internal::Ui::PasteSelectDialog m_ui;
    QPushButton *m_refreshButton;
};

} // namespace CodePaster

#endif // PASTESELECTDIALOG_H
